@@ -27,19 +27,19 @@ function(full.data, response, x, model, cplx=NULL, times=NULL, type=c("apparent"
       eval.times <- sort(times)
    }
    eval.times <- c(0, unique(eval.times[eval.times>0]))
-   if(is.list(cplx)){
-   if (type=="apparent"){
-      error <- pmpec(object=model, response=response, x=x, times=eval.times,
-         model.args=list(complexity=cplx$stepno), type="PErr", 
-         external.time=full.data$time, external.status=full.data$status, ...)
-      }
-
-   if (type=="noinf"){
-      error <- pmpec(object=model, response=response, x=x, times=eval.times,
-         model.args=list(complexity=cplx$stepno), type="NoInf", 
-         external.time=full.data$time, external.status=full.data$status, ...)
-      }
-} else {
+# # #    if(is.list(cplx)){
+# # #    if (type=="apparent"){
+# # #       error <- pmpec(object=model, response=response, x=x, times=eval.times,
+# # #          model.args=list(complexity=cplx$stepno), type="PErr", 
+# # #          external.time=full.data$time, external.status=full.data$status, ...)
+# # #       }
+# # # 
+# # #    if (type=="noinf"){
+# # #       error <- pmpec(object=model, response=response, x=x, times=eval.times,
+# # #          model.args=list(complexity=cplx$stepno), type="NoInf", 
+# # #          external.time=full.data$time, external.status=full.data$status, ...)
+# # #       }
+# # # } else {
 if (type=="apparent"){
       error <- pmpec(object=model, response=response, x=x, times=eval.times,
          model.args=list(complexity=cplx), type="PErr", 
@@ -52,7 +52,7 @@ if (type=="apparent"){
          external.time=full.data$time, external.status=full.data$status, ...)
       }
 
-}
+# # # }
 
    attr(error, "addattr") <- eval.times
    error
